@@ -244,7 +244,9 @@ load_pixbuf (struct sebie_s *sebie)
 							    sebie->model.scaled_width,
 							    sebie->model.scaled_height,
 							    GDK_INTERP_HYPER);
-  sebie->model.scaled_pixbuf = pixbuf_color_corrections(sebie->model.scaled_pixbuf_orig, sebie->model.image_gamma);
+  sebie->model.scaled_pixbuf = pixbuf_color_corrections(sebie->model.scaled_pixbuf_orig,
+							sebie->model.image_gamma,
+							sebie->model.image_grayscale);
   sebie->dirty_tags |= SEBIE_UPDATE_SCALED_PIXBUF;
   sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_RECT;
 #if 0
@@ -297,12 +299,13 @@ rotate_scaled(struct sebie_s *sebie, int direction)
 
 
 void
-apply_gamma(struct sebie_s *sebie)
+apply_color_corrections(struct sebie_s *sebie)
 {
   if (sebie->model.scaled_pixbuf_orig != NULL &&
       sebie->model.scaled_pixbuf != NULL) {
     GdkPixbuf *corr = pixbuf_color_corrections(sebie->model.scaled_pixbuf_orig,
-					       sebie->model.image_gamma);
+					       sebie->model.image_gamma,
+					       sebie->model.image_grayscale);
     g_object_unref(sebie->model.scaled_pixbuf);
     
     if (sebie->model.scaled_rotation == SEBIE_ROTATE_000) {
@@ -333,6 +336,7 @@ save_sebie_config(struct sebie_s *sebie)
       { "ImageOutputWidth",  CONFIG_INTEGER, &sebie->model.selection_fac_width, 1024},
       { "ImageOutputHeight", CONFIG_INTEGER, &sebie->model.selection_fac_height, 768},
       { "ImageGamma", CONFIG_DOUBLE, &sebie->model.image_gamma, 1.0},
+      { "ImageGrayscale", CONFIG_INTEGER, &sebie->model.image_grayscale, 0},
       { NULL, CONFIG_END, NULL, 0}
     };
     sebie_write_config(sebie->config_file, config_spec);
@@ -361,6 +365,7 @@ init_sebie_model(struct sebie_s *sebie)
     { "ImageOutputWidth",  CONFIG_INTEGER, &sebie->model.selection_fac_width, 1024},
     { "ImageOutputHeight", CONFIG_INTEGER, &sebie->model.selection_fac_height, 768},
     { "ImageGamma", CONFIG_DOUBLE, &sebie->model.image_gamma, 1.0},
+    { "ImageGrayscale", CONFIG_INTEGER, &sebie->model.image_grayscale, 0},
     { NULL, CONFIG_END, NULL, 0}
   };
   
