@@ -54,7 +54,8 @@ typedef enum sebie_model_tag_e {
   SEBIE_MODEL_INPUT_REGEX            =   2,
   SEBIE_MODEL_OUTPUT_FORMAT          =   4,
   SEBIE_MODEL_UPDATE_SELECTION_FAC   =   8,
-  SEBIE_MODEL_UPDATE_GAMMA           =  16
+  SEBIE_MODEL_UPDATE_GAMMA           =  16,
+  SEBIE_MODEL_UPDATE_GRAYSCALE       =  32
 } sebie_model_tag;
 
 typedef enum sebie_mouse_click_e {
@@ -81,7 +82,7 @@ typedef struct sebie_view_s {
   GtkWidget *label_selection_fac;
   GtkWidget *label_selection_gamma;
   GtkWidget *entry_selection_gamma;
-  GtkWidget *button7;
+  GtkWidget *button_grayscale;
   GtkWidget *hpaned1;
   GtkWidget *vbox2;
   GtkWidget *label_input_path;
@@ -126,6 +127,7 @@ typedef struct sebie_model_s {
   gint scaled_height;
   sebie_rotation scaled_rotation;
   gdouble image_gamma;
+  gint image_grayscale;
   /* the selection */
   sebie_mouse_click_type mouse_click_type;
   gint mouse_pos_lx;
@@ -157,8 +159,10 @@ typedef struct sebie_s {
 
 void sebie_update_view(struct sebie_s *sebie);
 void sebie_error_popup(struct sebie_s *sebie, gchar *error_str);
+void load_pixbuf (struct sebie_s *sebie);
 void sebie_update_file_list(struct sebie_s *sebie);
 void rotate_scaled(struct sebie_s *sebie, int direction);
+void apply_color_corrections(struct sebie_s *sebie);
 void save_sebie_config(struct sebie_s *sebie);
 
 /*
