@@ -182,7 +182,9 @@ on_button_save_clicked (GtkButton *button,
 					    x, y,
 					    width, height);
 
-  GdkPixbuf *corr = pixbuf_color_corrections(sub, sebie->model.image_gamma);
+  GdkPixbuf *corr = pixbuf_color_corrections(sub,
+					     sebie->model.image_gamma,
+					     sebie->model.image_grayscale);
 
   GdkPixbuf *save = gdk_pixbuf_scale_simple(corr, 
 					    fac_width,
@@ -304,7 +306,18 @@ on_entry_selection_gamma_changed (GtkEditable *editable,
   sebie->model.image_gamma = new_gamma;
   sebie->model_tags |= SEBIE_MODEL_UPDATE_GAMMA;
   sebie->dirty_tags |= SEBIE_UPDATE_IMAGE_GAMMA;
-  apply_gamma(sebie);
+  apply_color_corrections(sebie);
+}
+
+void
+on_button_grayscale_clicked(GtkButton *button,
+			    gpointer  user_data)
+{
+  struct sebie_s *sebie = (struct sebie_s *)user_data;
+  sebie->model.image_grayscale = !sebie->model.image_grayscale;
+  printf("set new image_grayscale = %d\n", sebie->model.image_grayscale);
+  sebie->model_tags |= SEBIE_MODEL_UPDATE_GRAYSCALE;
+  apply_color_corrections(sebie);
 }
 
 gboolean
