@@ -186,17 +186,14 @@ init_sebie_view(struct sebie_s *sebie)
   gtk_widget_set_size_request (sebie->view.entry_selection_gamma, 50, 20);
   gtk_entry_set_max_length (GTK_ENTRY (sebie->view.entry_selection_gamma), 5);
 
-
-#if 0
-  sebie->view.button7 = gtk_toolbar_append_element (GTK_TOOLBAR (sebie->view.toolbar1),
-                                GTK_TOOLBAR_CHILD_BUTTON,
-                                NULL,
-                                _("button7"),
-                                NULL, NULL,
-                                NULL, NULL, NULL);
+  sebie->view.button_grayscale = gtk_toolbar_append_element (GTK_TOOLBAR (sebie->view.toolbar1),
+							     GTK_TOOLBAR_CHILD_BUTTON,
+							     NULL,
+							     _("Grayscale"),
+							     NULL, NULL,
+							     NULL, NULL, NULL);
   gtk_label_set_use_underline (GTK_LABEL (((GtkToolbarChild*) (g_list_last (GTK_TOOLBAR (sebie->view.toolbar1)->children)->data))->label), TRUE);
-  gtk_widget_show (sebie->view.button7);
-#endif
+  gtk_widget_show (sebie->view.button_grayscale);
 
   sebie->view.hpaned1 = gtk_hpaned_new ();
   gtk_widget_show (sebie->view.hpaned1);
@@ -316,6 +313,9 @@ init_sebie_view(struct sebie_s *sebie)
   g_signal_connect ((gpointer) sebie->view.entry_selection_gamma, "changed",
                     G_CALLBACK (on_entry_selection_gamma_changed),
                     sebie);
+  g_signal_connect ((gpointer) sebie->view.button_grayscale, "clicked",
+                    G_CALLBACK (on_button_grayscale_clicked),
+                    sebie);
 
   gtk_widget_set_events (sebie->view.drawingarea1, GDK_EXPOSURE_MASK
 			 | GDK_LEAVE_NOTIFY_MASK
